#[repr(u8)]pub enum ColorLoopAction {
Deactivate = 0,
Activatefromcolorloopstartenhancedhue = 1,
Activatefromenhancedcurrenthue = 2,
}Variants
Deactivate = 0
De-activate the color loop.
Activatefromcolorloopstartenhancedhue = 1
Activate the color loop from the value in the ColorLoopStartEnhancedHue field.
Activatefromenhancedcurrenthue = 2
Activate the color loop from the value of the EnhancedCurrentHue attribute.
Implementations