#[repr(u8)]pub enum ColorMode {
Currenthueandcurrentsaturation = 0,
Currentxandcurrenty = 1,
Colortemperaturemireds = 2,
}Variants
Currenthueandcurrentsaturation = 0
The current hue and saturation attributes determine the color.
Currentxandcurrenty = 1
The current X and Y attributes determine the color.
Colortemperaturemireds = 2
The color temperature attribute determines the color.
Implementations