#[repr(u8)]pub enum DriftCompensation {
None = 0,
Otherorunknown = 1,
Temperaturemonitoring = 2,
Opticalluminancemonitoringandfeedback = 3,
Opticalcolormonitoringandfeedback = 4,
}Variants
None = 0
There is no compensation.
Otherorunknown = 1
The compensation is based on other or unknown mechanism.
Temperaturemonitoring = 2
The compensation is based on temperature monitoring.
Opticalluminancemonitoringandfeedback = 3
The compensation is based on optical luminance monitoring and feedback.
Opticalcolormonitoringandfeedback = 4
The compensation is based on optical color monitoring and feedback.
Implementations