#[repr(u8)]pub enum EnhancedColorMode {
Currenthueandcurrentsaturation = 0,
Currentxandcurrenty = 1,
Colortemperaturemireds = 2,
Enhancedcurrenthueandcurrentsaturation = 3,
}Variants
Currenthueandcurrentsaturation = 0
The current hue and saturation attributes determine the color.
Currentxandcurrenty = 1
The current X and Y attributes determine the color.
Colortemperaturemireds = 2
The color temperature attribute determines the color.
Enhancedcurrenthueandcurrentsaturation = 3
The enhanced current hue and saturation attributes determine the color.
Implementations